@@ -36,9 +36,9 @@ public:
 
 	void setInfo( const ICQFullInfo& info );
 
-	virtual bool forMe( const Transfer* transfer ) const;
-	virtual bool take( Transfer* transfer );
-	virtual void onGo();
+	bool forMe( const Transfer* transfer ) const Q_DECL_OVERRIDE;
+	bool take( Transfer* transfer ) Q_DECL_OVERRIDE;
+	void onGo() Q_DECL_OVERRIDE;
 
 private:
 	ICQFullInfo m_info;
